@@ -5,7 +5,7 @@
 #
 # Copyright 2003 YMIRLINK,Inc.
 # -----------------------------------------------------------------------------
-# $Id: Html.pm,v 1.14 2004/08/14 11:09:10 hio Exp $
+# $Id: /perl/Pod-MultiLang/lib/Pod/MultiLang/Html.pm 116 2006-07-09T15:52:31.021201Z hio  $
 # -----------------------------------------------------------------------------
 package Pod::MultiLang::Html;
 use strict;
@@ -36,6 +36,7 @@ use constant
   PARA_BEGIN     => 7,
   PARA_END       => 8,
   PARA_FOR       => 9,
+  PARA_ENCODING  => 10,
 };
 use constant
 {
@@ -515,7 +516,7 @@ sub buildhtml
   }
   $ret;
 }
-sub a2s{ join('-',map{defined($_)?"[$_]":'{undef}'}@_) }
+sub _a2s{ join('-',map{defined($_)?"[$_]":'{undef}'}@_) }
 
 sub _find_lang_index
 {
@@ -544,7 +545,7 @@ sub _buildhtml_parse
     $ptree = $ptree->parse_tree();
   }
   my @children = can($ptree,'children')?$ptree->children():isa($ptree,'ARRAY')?@$ptree:die "unknown object : $ptree";
-  #print STDERR "in: @{[scalar@children]} ",a2s(@children),"\n";
+  #print STDERR "in: @{[scalar@children]} ",_a2s(@children),"\n";
   foreach (@children)
   {
     if( !ref($_) )
@@ -657,7 +658,7 @@ sub _buildhtml_parse
       # normal iseq.
       #print STDERR "normal iseq\n";
       my @child = $parser->_buildhtml_parse($_->parse_tree());
-      #print STDERR"  child : $#child ".a2s(@child)."\n";
+      #print STDERR"  child : $#child "._a2s(@child)."\n";
       # default_lang が未定義だったら, 言語指定なし部分を充てる.
       for( my $i=0; $i<=$#{$parser->{langs}}; ++$i )
       {
@@ -707,10 +708,10 @@ sub _buildhtml_parse
       $ret[$i] .= $child[-1];
       last;
     }
-    #print STDERR "  iseq: $#ret ",a2s(@ret),"\n";
+    #print STDERR "  iseq: $#ret ",_a2s(@ret),"\n";
   }
   $ret[-1]=~/\S/ or $ret[-1]='';
-  #print "out: @{[scalar@ret]} ",a2s(@ret),"\n";
+  #print "out: @{[scalar@ret]} ",_a2s(@ret),"\n";
   @ret;
 }
 
@@ -904,7 +905,9 @@ sub addindex
 #
 sub end_pod
 {
-  my ($parser, $command, $paragraph, $line_num) = @_;
+  my $parser = shift;
+  my ($command, $paragraph, $line_num) = @_;
+	$parser->SUPER::end_pod(@_);
   
   if( !@{$parser->{paras}} )
   {
@@ -1325,6 +1328,13 @@ sub output_html
       $outtext .= "<!-- end [$mode] behavior [$fin->[STK_BEHAVIOR]] (started by [$fin->[STK_PARAOBJ][PARAINFO_CONTENT]]) -->\n";
     }elsif( $paratype==PARA_FOR )
     {
+    }elsif( $paratype==PARA_ENCODING )
+    {
+      my $text = $_->[PARAINFO_CONTENT];
+      my $cmd = $paraobj->cmd_name();
+      $text = $parser->_from_to($text);
+      $text =~ s/\n(\s*\n)+/\n/g;
+      $outtext = "<!-- =$cmd $text -->\n";
     }else
     {
       $parser->verbmsg(VERBOSE_ERROR,"what\'s got?? [$paratype]");
@@ -1505,19 +1515,6 @@ sub resolveLink
   wantarray?@list:$list[0];
 }
 
-# -----------------------------------------------------------------------------
-# $parser->parseLang($text);
-#   J<> の中身を解析.
-#   
-#
-sub parseLang
-{
-  my $text = $_[1];
-  defined($text) or return ('','');
-  my $lang = $text =~ s,^\s*(\w+)\s*[/;]\s*,, ? $1 : '';
-  ($lang,$text);
-}
-
 1;
 __END__
 # -----------------------------------------------------------------------------
